@@ -15,6 +15,18 @@ class ProductFees(Client):
 
         Returns fees for sku
 
+        Examples:
+            literal blocks::
+
+                ProductFees().get_product_fees_estimate_for_sku("UmaS1", 10, currency='USD', shipping_price=10, is_fba=False,
+                                                          points={
+                                                              "PointsNumber": 0,
+                                                              "PointsMonetaryValue": {
+                                                                  "CurrencyCode": "USD",
+                                                                  "Amount": 0
+                                                              }
+                                                          })
+
         Args:
             seller_sku:
             price:
@@ -40,6 +52,18 @@ class ProductFees(Client):
 
         Returns fees for asin
 
+        Examples:
+            literal blocks::
+
+                ProductFees().get_product_fees_estimate_for_asin("UmaS1", 10, currency='USD', shipping_price=10, is_fba=False,
+                                                           points={
+                                                               "PointsNumber": 0,
+                                                               "PointsMonetaryValue": {
+                                                                   "CurrencyCode": "USD",
+                                                                   "Amount": 0
+                                                               }
+                                                           })
+
         Args:
             asin:
             price:
